@@ -386,3 +386,8 @@ class RetailerProvider(ReboticsBaseProvider):
             json={
                 'image': image_id
             }, content_type='application/json')
+
+    @remote_service('api/v4/processing/actions/{id}/spacial')
+    def get_spacial_data(self, scan_id):
+        """Can yield permission error. Internal usage intended"""
+        return self.session.get(id=scan_id)
