@@ -21,7 +21,7 @@ def test_classification_packing():
     assert entry.label == '123123123'
     assert entry.feature == '123123123123123'
     internal_filename = entry.filename
-    assert internal_filename == 'image_400x400.png'
+    assert internal_filename == 'image_1.png'
 
     # testing if it can be dumped to the FS
     og_file = pathlib.Path('db/custom_folder') / internal_filename
